diff --git a/apps/accessibility/css/fontdyslexic.scss b/apps/accessibility/css/fontdyslexic.scss
index 45638271f90f40d6094ce03904a0cc65615e7451..8c7a2f51e3588cf7d8b8642f71eec9c3605de29e 100644
--- a/apps/accessibility/css/fontdyslexic.scss
+++ b/apps/accessibility/css/fontdyslexic.scss
@@ -1,22 +1,15 @@
 @font-face {
 	font-family: 'OpenDyslexic';
 	font-style: normal;
-	font-weight: 300;
+	font-weight: 400;
 	src: url('../fonts/OpenDyslexic-Regular.woff') format('woff');
 }
 
 @font-face {
 	font-family: 'OpenDyslexic';
 	font-style: normal;
-	font-weight: normal;
-	src: url('../fonts/OpenDyslexic-Regular.woff') format('woff');
-}
-
-@font-face {
-	font-family: 'OpenDyslexic';
-	font-style: normal;
-	font-weight: 600;
+	font-weight: 700;
 	src: url('../fonts/OpenDyslexic-Bold.woff') format('woff');
 }
 
-$font-face: OpenDyslexic, 'Nunito', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
+$font-face: OpenDyslexic, 'Noto Sans', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
diff --git a/apps/user_ldap/css/renewPassword.css b/apps/user_ldap/css/renewPassword.css
index 9f49dc23cae15f35f55aa58f980b05d76c79abf4..36f7054dba800116499f84ef93c5e76f2f94990f 100644
--- a/apps/user_ldap/css/renewPassword.css
+++ b/apps/user_ldap/css/renewPassword.css
@@ -22,7 +22,7 @@
 .tooltip {
 	position:absolute;
 	display:block;
-	font-family: 'Nunito', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
+	font-family: 'Noto Sans', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
 	font-style:normal;
 	font-weight:400;
 	letter-spacing:normal;
diff --git a/core/css/fonts.scss b/core/css/fonts.scss
index 1e0b14af22f4ac60c4b9aeaf615ddaf42ec95e87..195a2beb4aa672f3fb571454fdc5eecc894024b1 100644
--- a/core/css/fonts.scss
+++ b/core/css/fonts.scss
@@ -1,43 +1,144 @@
+/* cyrillic-ext */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-cyrillic-ext.woff2') format('woff2');
+  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
+}
+/* cyrillic */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-cyrillic.woff2') format('woff2');
+  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
+}
+/* devanagari */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-devanagari.woff2') format('woff2');
+  unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;
+}
+/* greek-ext */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-greek-ext.woff2') format('woff2');
+  unicode-range: U+1F00-1FFF;
+}
+/* greek */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-greek.woff2') format('woff2');
+  unicode-range: U+0370-03FF;
+}
+/* vietnamese */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-vietnamese.woff2') format('woff2');
+  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
+}
 /* latin-ext */
 @font-face {
-	font-family: 'Nunito';
-	font-style: normal;
-	font-weight: 400; /* normal */
-	src: local('Nunito Regular'), local('Nunito-Regular'),
-		url('../fonts/Nunito-Regular-latin-ext.woff2') format('woff2'),
-		url('../fonts/Nunito-Regular.ttf') format('truetype');
-	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-latin-ext.woff2') format('woff2');
+  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
 }
-
 /* latin */
 @font-face {
-	font-family: 'Nunito';
-	font-style: normal;
-	font-weight: 400; /* normal */
-	src: local('Nunito Regular'), local('Nunito-Regular'),
-		url('../fonts/Nunito-Regular.woff2') format('woff2'),
-		url('../fonts/Nunito-Regular.ttf') format('truetype');
-	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-latin.woff2') format('woff2');
+  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
+}
+/* cyrillic-ext */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-cyrillic-ext.woff2') format('woff2');
+  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
+}
+/* cyrillic */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-cyrillic.woff2') format('woff2');
+  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
+}
+/* devanagari */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-devanagari.woff2') format('woff2');
+  unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;
+}
+/* greek-ext */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-greek-ext.woff2') format('woff2');
+  unicode-range: U+1F00-1FFF;
+}
+/* greek */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-greek.woff2') format('woff2');
+  unicode-range: U+0370-03FF;
+}
+/* vietnamese */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-vietnamese.woff2') format('woff2');
+  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
 }
-
 /* latin-ext */
 @font-face {
-	font-family: 'Nunito';
-	font-style: normal;
-	font-weight: 700; /* bold */
-	src: local('Nunito Bold'), local('Nunito-Bold'),
-		url('../fonts/Nunito-Bold-latin-ext.woff2') format('woff2'),
-		url('../fonts/Nunito-Bold.ttf') format('truetype');
-	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-latin-ext.woff2') format('woff2');
+  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
 }
-
 /* latin */
 @font-face {
-	font-family: 'Nunito';
-	font-style: normal;
-	font-weight: 700; /* bold */
-	src: local('Nunito Bold'), local('Nunito-Bold'),
-		url('../fonts/Nunito-Bold.woff2') format('woff2'),
-		url('../fonts/Nunito-Bold.ttf') format('truetype');
-	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-latin.woff2') format('woff2');
+  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
 }
diff --git a/core/css/guest.css b/core/css/guest.css
index 57fe966d26fb0ad25aa88c5bcc189a7c055993f9..3b0d1efa4d9db7b45a55c7ff01ac95faf6875b4c 100644
--- a/core/css/guest.css
+++ b/core/css/guest.css
@@ -19,7 +19,7 @@ body {
 	font-weight: normal;
 	font-size: .8em;
 	line-height: 1.6em;
-	font-family: 'Nunito', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
+	font-family: 'Noto Sans', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
 	color: #000;
 	text-align: center;
 	background-color: #0082c9;
@@ -183,7 +183,7 @@ form #datadirField legend {
 
 
 input, textarea, select, button, div[contenteditable=true] {
-	font-family: 'Nunito', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
+	font-family: 'Noto Sans', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
 }
 input,
 input:not([type='range']),
@@ -850,46 +850,149 @@ a.legal {
 }
 
 
+/* fonts.scss ---------------------------------------------------- */
+
+/* cyrillic-ext */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-cyrillic-ext.woff2') format('woff2');
+  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
+}
+/* cyrillic */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-cyrillic.woff2') format('woff2');
+  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
+}
+/* devanagari */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-devanagari.woff2') format('woff2');
+  unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;
+}
+/* greek-ext */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-greek-ext.woff2') format('woff2');
+  unicode-range: U+1F00-1FFF;
+}
+/* greek */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-greek.woff2') format('woff2');
+  unicode-range: U+0370-03FF;
+}
+/* vietnamese */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-vietnamese.woff2') format('woff2');
+  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
+}
 /* latin-ext */
 @font-face {
-	font-family: 'Nunito';
-	font-style: normal;
-	font-weight: 400; /* normal */
-	src: local('Nunito Regular'), local('Nunito-Regular'),
-		url('../fonts/Nunito-Regular-latin-ext.woff2') format('woff2'),
-		url('../fonts/Nunito-Regular.ttf') format('truetype');
-	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-latin-ext.woff2') format('woff2');
+  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
 }
-
 /* latin */
 @font-face {
-	font-family: 'Nunito';
-	font-style: normal;
-	font-weight: 400; /* normal */
-	src: local('Nunito Regular'), local('Nunito-Regular'),
-		url('../fonts/Nunito-Regular.woff2') format('woff2'),
-		url('../fonts/Nunito-Regular.ttf') format('truetype');
-	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 400;
+  font-display: swap;
+  src: local('Noto Sans'), local('NotoSans'), url('../fonts/NotoSans-Regular-latin.woff2') format('woff2');
+  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
+}
+/* cyrillic-ext */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-cyrillic-ext.woff2') format('woff2');
+  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
+}
+/* cyrillic */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-cyrillic.woff2') format('woff2');
+  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
+}
+/* devanagari */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-devanagari.woff2') format('woff2');
+  unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;
+}
+/* greek-ext */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-greek-ext.woff2') format('woff2');
+  unicode-range: U+1F00-1FFF;
+}
+/* greek */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-greek.woff2') format('woff2');
+  unicode-range: U+0370-03FF;
+}
+/* vietnamese */
+@font-face {
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-vietnamese.woff2') format('woff2');
+  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
 }
-
 /* latin-ext */
 @font-face {
-	font-family: 'Nunito';
-	font-style: normal;
-	font-weight: 700; /* bold */
-	src: local('Nunito Bold'), local('Nunito-Bold'),
-		url('../fonts/Nunito-Bold-latin-ext.woff2') format('woff2'),
-		url('../fonts/Nunito-Bold.ttf') format('truetype');
-	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-latin-ext.woff2') format('woff2');
+  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
 }
-
 /* latin */
 @font-face {
-	font-family: 'Nunito';
-	font-style: normal;
-	font-weight: 700; /* bold */
-	src: local('Nunito Bold'), local('Nunito-Bold'),
-		url('../fonts/Nunito-Bold.woff2') format('woff2'),
-		url('../fonts/Nunito-Bold.ttf') format('truetype');
-	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
+  font-family: 'Noto Sans';
+  font-style: normal;
+  font-weight: 700;
+  font-display: swap;
+  src: local('Noto Sans Bold'), local('NotoSans-Bold'), url('../fonts/NotoSans-Bold-latin.woff2') format('woff2');
+  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
 }
diff --git a/core/css/tooltip.scss b/core/css/tooltip.scss
index ca08e5808c4bf18259a3255107b4089b706ab80d..329d3d75bcf8b4281fd23ea5e5aa6d16cb2b8f02 100644
--- a/core/css/tooltip.scss
+++ b/core/css/tooltip.scss
@@ -13,7 +13,7 @@
 .tooltip {
     position: absolute;
     display: block;
-    font-family: 'Nunito', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
+    font-family: 'Noto Sans', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif;
     font-style: normal;
     font-weight: normal;
     letter-spacing: normal;
diff --git a/core/css/variables.scss b/core/css/variables.scss
index 960371c25366dfe60b8d30dced810d9ef24c6b37..8811e60cc674edd7c0c3bad363ca5806384ffb90 100644
--- a/core/css/variables.scss
+++ b/core/css/variables.scss
@@ -79,7 +79,7 @@ $border-radius-large: 10px !default;
 // Pill-style button, value is large so big buttons also have correct roundness
 $border-radius-pill: 100px !default;
 
-$font-face: 'Nunito', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif !default;
+$font-face: 'Noto Sans', 'Open Sans', Frutiger, Calibri, 'Myriad Pro', Myriad, sans-serif !default;
 
 $animation-quick: 100ms;
 $animation-slow: 300ms;
diff --git a/core/fonts/OFL.txt b/core/fonts/LICENSE_OFL.txt
similarity index 71%
rename from core/fonts/OFL.txt
rename to core/fonts/LICENSE_OFL.txt
index 601d961cd9035a6c500150f1ecdb54f7e7cb9172..d952d62c065f3f35fb83a173496e90b21525aef3 100644
--- a/core/fonts/OFL.txt
+++ b/core/fonts/LICENSE_OFL.txt
@@ -1,29 +1,28 @@
-Copyright 2014 The Nunito Project Authors (contact@sansoxygen.com)
+This Font Software is licensed under the SIL Open Font License,
+Version 1.1.
 
-This Font Software is licensed under the SIL Open Font License, Version 1.1.
 This license is copied below, and is also available with a FAQ at:
 http://scripts.sil.org/OFL
 
-
 -----------------------------------------------------------
 SIL OPEN FONT LICENSE Version 1.1 - 26 February 2007
 -----------------------------------------------------------
 
 PREAMBLE
 The goals of the Open Font License (OFL) are to stimulate worldwide
-development of collaborative font projects, to support the font creation
-efforts of academic and linguistic communities, and to provide a free and
-open framework in which fonts may be shared and improved in partnership
-with others.
+development of collaborative font projects, to support the font
+creation efforts of academic and linguistic communities, and to
+provide a free and open framework in which fonts may be shared and
+improved in partnership with others.
 
 The OFL allows the licensed fonts to be used, studied, modified and
 redistributed freely as long as they are not sold by themselves. The
-fonts, including any derivative works, can be bundled, embedded, 
+fonts, including any derivative works, can be bundled, embedded,
 redistributed and/or sold with any software provided that any reserved
 names are not used by derivative works. The fonts and derivatives,
 however, cannot be released under any other type of license. The
-requirement for fonts to remain under this license does not apply
-to any document created using the fonts or their derivatives.
+requirement for fonts to remain under this license does not apply to
+any document created using the fonts or their derivatives.
 
 DEFINITIONS
 "Font Software" refers to the set of files released by the Copyright
@@ -33,25 +32,25 @@ include source files, build scripts and documentation.
 "Reserved Font Name" refers to any names specified as such after the
 copyright statement(s).
 
-"Original Version" refers to the collection of Font Software components as
-distributed by the Copyright Holder(s).
+"Original Version" refers to the collection of Font Software
+components as distributed by the Copyright Holder(s).
 
-"Modified Version" refers to any derivative made by adding to, deleting,
-or substituting -- in part or in whole -- any of the components of the
-Original Version, by changing formats or by porting the Font Software to a
-new environment.
+"Modified Version" refers to any derivative made by adding to,
+deleting, or substituting -- in part or in whole -- any of the
+components of the Original Version, by changing formats or by porting
+the Font Software to a new environment.
 
 "Author" refers to any designer, engineer, programmer, technical
 writer or other person who contributed to the Font Software.
 
 PERMISSION & CONDITIONS
 Permission is hereby granted, free of charge, to any person obtaining
-a copy of the Font Software, to use, study, copy, merge, embed, modify,
-redistribute, and sell modified and unmodified copies of the Font
-Software, subject to the following conditions:
+a copy of the Font Software, to use, study, copy, merge, embed,
+modify, redistribute, and sell modified and unmodified copies of the
+Font Software, subject to the following conditions:
 
-1) Neither the Font Software nor any of its individual components,
-in Original or Modified Versions, may be sold by itself.
+1) Neither the Font Software nor any of its individual components, in
+Original or Modified Versions, may be sold by itself.
 
 2) Original or Modified Versions of the Font Software may be bundled,
 redistributed and/or sold with any software, provided that each copy
@@ -61,9 +60,9 @@ in the appropriate machine-readable metadata fields within text or
 binary files as long as those fields can be easily viewed by the user.
 
 3) No Modified Version of the Font Software may use the Reserved Font
-Name(s) unless explicit written permission is granted by the corresponding
-Copyright Holder. This restriction only applies to the primary font name as
-presented to the users.
+Name(s) unless explicit written permission is granted by the
+corresponding Copyright Holder. This restriction only applies to the
+primary font name as presented to the users.
 
 4) The name(s) of the Copyright Holder(s) or the Author(s) of the Font
 Software shall not be used to promote, endorse or advertise any
@@ -74,8 +73,8 @@ permission.
 5) The Font Software, modified or unmodified, in part or in whole,
 must be distributed entirely under this license, and must not be
 distributed under any other license. The requirement for fonts to
-remain under this license does not apply to any document created
-using the Font Software.
+remain under this license does not apply to any document created using
+the Font Software.
 
 TERMINATION
 This license becomes null and void if any of the above conditions are
diff --git a/core/fonts/NotoSans-Bold-cyrillic-ext.woff2 b/core/fonts/NotoSans-Bold-cyrillic-ext.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..d3a6ecb475a113466a235d06475676342d094c22
Binary files /dev/null and b/core/fonts/NotoSans-Bold-cyrillic-ext.woff2 differ
diff --git a/core/fonts/NotoSans-Bold-cyrillic.woff2 b/core/fonts/NotoSans-Bold-cyrillic.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..937e522c7e8c3d69d83d14f47a4f8d402fbd0785
Binary files /dev/null and b/core/fonts/NotoSans-Bold-cyrillic.woff2 differ
diff --git a/core/fonts/NotoSans-Bold-devanagari.woff2 b/core/fonts/NotoSans-Bold-devanagari.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..905be68372434f559398a2bedf866c5de7d8a23c
Binary files /dev/null and b/core/fonts/NotoSans-Bold-devanagari.woff2 differ
diff --git a/core/fonts/NotoSans-Bold-greek-ext.woff2 b/core/fonts/NotoSans-Bold-greek-ext.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..01db534189d533afdaa5622d22024a48b08b0879
Binary files /dev/null and b/core/fonts/NotoSans-Bold-greek-ext.woff2 differ
diff --git a/core/fonts/NotoSans-Bold-greek.woff2 b/core/fonts/NotoSans-Bold-greek.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..627e7f1ef8b32109bd710af9f249e70ce9ae1003
Binary files /dev/null and b/core/fonts/NotoSans-Bold-greek.woff2 differ
diff --git a/core/fonts/NotoSans-Bold-latin-ext.woff2 b/core/fonts/NotoSans-Bold-latin-ext.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..8b580a51948b3cecd0e39136aa03d9813dfb68e7
Binary files /dev/null and b/core/fonts/NotoSans-Bold-latin-ext.woff2 differ
diff --git a/core/fonts/NotoSans-Bold-latin.woff2 b/core/fonts/NotoSans-Bold-latin.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..1f16cc33d535b522989d2734a98f8557a7282f8e
Binary files /dev/null and b/core/fonts/NotoSans-Bold-latin.woff2 differ
diff --git a/core/fonts/NotoSans-Bold-vietnamese.woff2 b/core/fonts/NotoSans-Bold-vietnamese.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..d57f6d39e111dfe6d569479ef73733479423ced2
Binary files /dev/null and b/core/fonts/NotoSans-Bold-vietnamese.woff2 differ
diff --git a/core/fonts/NotoSans-Bold.ttf b/core/fonts/NotoSans-Bold.ttf
new file mode 100644
index 0000000000000000000000000000000000000000..ab11d316397b9652ce96c2675f3b7a46cf6de13e
Binary files /dev/null and b/core/fonts/NotoSans-Bold.ttf differ
diff --git a/core/fonts/NotoSans-Regular-cyrillic-ext.woff2 b/core/fonts/NotoSans-Regular-cyrillic-ext.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..ec414480000a6f195fd578a0768756ec6b5ffe04
Binary files /dev/null and b/core/fonts/NotoSans-Regular-cyrillic-ext.woff2 differ
diff --git a/core/fonts/NotoSans-Regular-cyrillic.woff2 b/core/fonts/NotoSans-Regular-cyrillic.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..882cbba0988f20505c06738128aa0f016f6be506
Binary files /dev/null and b/core/fonts/NotoSans-Regular-cyrillic.woff2 differ
diff --git a/core/fonts/NotoSans-Regular-devanagari.woff2 b/core/fonts/NotoSans-Regular-devanagari.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..f76bdc4de1d89c15a4a2f95e08407b64ed16bb24
Binary files /dev/null and b/core/fonts/NotoSans-Regular-devanagari.woff2 differ
diff --git a/core/fonts/NotoSans-Regular-greek-ext.woff2 b/core/fonts/NotoSans-Regular-greek-ext.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..70c40413a3a8a273eef7843b72e5cb146337bd5f
Binary files /dev/null and b/core/fonts/NotoSans-Regular-greek-ext.woff2 differ
diff --git a/core/fonts/NotoSans-Regular-greek.woff2 b/core/fonts/NotoSans-Regular-greek.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..d95083535a5edfa824c2aae128c0b3bea5034b47
Binary files /dev/null and b/core/fonts/NotoSans-Regular-greek.woff2 differ
diff --git a/core/fonts/NotoSans-Regular-latin-ext.woff2 b/core/fonts/NotoSans-Regular-latin-ext.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..62becf88cb9ddf71b13635b791b75db85f382aa8
Binary files /dev/null and b/core/fonts/NotoSans-Regular-latin-ext.woff2 differ
diff --git a/core/fonts/NotoSans-Regular-latin.woff2 b/core/fonts/NotoSans-Regular-latin.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..cf2b74a64ddecf3d3bb1cc8e0c8335d5b742e8c3
Binary files /dev/null and b/core/fonts/NotoSans-Regular-latin.woff2 differ
diff --git a/core/fonts/NotoSans-Regular-vietnamese.woff2 b/core/fonts/NotoSans-Regular-vietnamese.woff2
new file mode 100644
index 0000000000000000000000000000000000000000..6d331d80b2d7b0cbafcbeb57c8fa374b3bb76347
Binary files /dev/null and b/core/fonts/NotoSans-Regular-vietnamese.woff2 differ
diff --git a/core/fonts/NotoSans-Regular.ttf b/core/fonts/NotoSans-Regular.ttf
new file mode 100644
index 0000000000000000000000000000000000000000..a1b8994edeacd70067de843a4691b15a0ce5921b
Binary files /dev/null and b/core/fonts/NotoSans-Regular.ttf differ
diff --git a/core/fonts/Nunito-Bold-latin-ext.woff2 b/core/fonts/Nunito-Bold-latin-ext.woff2
deleted file mode 100644
index d69ce0d32e91f710009f7bf801f7bbb313886b00..0000000000000000000000000000000000000000
Binary files a/core/fonts/Nunito-Bold-latin-ext.woff2 and /dev/null differ
diff --git a/core/fonts/Nunito-Bold.ttf b/core/fonts/Nunito-Bold.ttf
deleted file mode 100644
index d2037334825139850abeb130b66f86b52e5b48cf..0000000000000000000000000000000000000000
Binary files a/core/fonts/Nunito-Bold.ttf and /dev/null differ
diff --git a/core/fonts/Nunito-Bold.woff2 b/core/fonts/Nunito-Bold.woff2
deleted file mode 100644
index fef6db672d6a6e3ececa60e7fc73178a89753dd1..0000000000000000000000000000000000000000
Binary files a/core/fonts/Nunito-Bold.woff2 and /dev/null differ
diff --git a/core/fonts/Nunito-Regular-latin-ext.woff2 b/core/fonts/Nunito-Regular-latin-ext.woff2
deleted file mode 100644
index 8c7dd0f9898562b701e8f17c0d437511a5d508fd..0000000000000000000000000000000000000000
Binary files a/core/fonts/Nunito-Regular-latin-ext.woff2 and /dev/null differ
diff --git a/core/fonts/Nunito-Regular.ttf b/core/fonts/Nunito-Regular.ttf
deleted file mode 100644
index 93a3f3e78ea67328c1dedb00e002b29f7c1a3d61..0000000000000000000000000000000000000000
Binary files a/core/fonts/Nunito-Regular.ttf and /dev/null differ
diff --git a/core/fonts/Nunito-Regular.woff2 b/core/fonts/Nunito-Regular.woff2
deleted file mode 100644
index 28b65a12e678579b5784cc1699520c445d99a479..0000000000000000000000000000000000000000
Binary files a/core/fonts/Nunito-Regular.woff2 and /dev/null differ
diff --git a/core/js/tests/specs/setupchecksSpec.js b/core/js/tests/specs/setupchecksSpec.js
index b5248add98441645afc9d90fd319024694bb4eb4..2f28dcdaef787881a579b925faa1539f1ac00048 100644
--- a/core/js/tests/specs/setupchecksSpec.js
+++ b/core/js/tests/specs/setupchecksSpec.js
@@ -145,7 +145,7 @@ describe('OC.SetupChecks tests', function() {
 
 	describe('checkWOFF2Loading', function() {
 		it('should fail with another response status code than the expected one', function(done) {
-			var async = OC.SetupChecks.checkWOFF2Loading(OC.filePath('core', '', 'fonts/Nunito-Regular.woff2'), 'http://example.org/PLACEHOLDER');
+			var async = OC.SetupChecks.checkWOFF2Loading(OC.filePath('core', '', 'fonts/NotoSans-Regular-latin.woff2'), 'http://example.org/PLACEHOLDER');
 
 			suite.server.requests[0].respond(302);
 
@@ -159,7 +159,7 @@ describe('OC.SetupChecks tests', function() {
 		});
 
 		it('should return no error with the expected response status code', function(done) {
-			var async = OC.SetupChecks.checkWOFF2Loading(OC.filePath('core', '', 'fonts/Nunito-Regular.woff2'), 'http://example.org/PLACEHOLDER');
+			var async = OC.SetupChecks.checkWOFF2Loading(OC.filePath('core', '', 'fonts/NotoSans-Regular-latin.woff2'), 'http://example.org/PLACEHOLDER');
 
 			suite.server.requests[0].respond(200);
 
diff --git a/lib/private/Preview/TXT.php b/lib/private/Preview/TXT.php
index 2bb121775d6b635b570ebece00494e1379bfc8aa..c90c9e388234071b7fba7e63cd754343b35348ac 100644
--- a/lib/private/Preview/TXT.php
+++ b/lib/private/Preview/TXT.php
@@ -70,7 +70,7 @@ class TXT extends Provider {
 
 		$fontFile  = __DIR__;
 		$fontFile .= '/../../../core';
-		$fontFile .= '/fonts/Nunito-Regular.ttf';
+		$fontFile .= '/fonts/NotoSans-Regular.ttf';
 
 		$canUseTTF = function_exists('imagettftext');
 
diff --git a/settings/js/admin.js b/settings/js/admin.js
index 6074a3ae2c975aafedcd36b4d4a7ac5b0c1d3639..6f3db81655d39a2237b4da320e75b5b14dfa0303 100644
--- a/settings/js/admin.js
+++ b/settings/js/admin.js
@@ -255,7 +255,7 @@ $(document).ready(function(){
 			OC.SetupChecks.checkProviderUrl(OC.getRootPath() + '/ocs-provider/', OC.theme.docPlaceholderUrl, $('#postsetupchecks').data('check-wellknown') === true),
 			OC.SetupChecks.checkSetup(),
 			OC.SetupChecks.checkGeneric(),
-			OC.SetupChecks.checkWOFF2Loading(OC.filePath('core', '', 'fonts/Nunito-Regular.woff2'), OC.theme.docPlaceholderUrl),
+			OC.SetupChecks.checkWOFF2Loading(OC.filePath('core', '', 'fonts/NotoSans-Regular-latin.woff2'), OC.theme.docPlaceholderUrl),
 			OC.SetupChecks.checkDataProtected()
 		).then(function (check1, check2, check3, check4, check5, check6, check7, check8, check9, check10) {
 			var messages = [].concat(check1, check2, check3, check4, check5, check6, check7, check8, check9, check10);
diff --git a/tests/lib/Avatar/UserAvatarTest.php b/tests/lib/Avatar/UserAvatarTest.php
index 049725c78c9f36ec6f24810a8d509b093b919eb4..061866bedb0f2c4f6b2c9429e9b0b6e740f09542 100644
--- a/tests/lib/Avatar/UserAvatarTest.php
+++ b/tests/lib/Avatar/UserAvatarTest.php
@@ -235,7 +235,7 @@ class UserAvatarTest extends \Test\TestCase {
 		$svg = '<?xml version="1.0" encoding="UTF-8" standalone="no"?>
 		<svg width="64" height="64" version="1.1" viewBox="0 0 500 500" xmlns="http://www.w3.org/2000/svg">
 			<rect width="100%" height="100%" fill="#0082c9"></rect>
-			<text x="50%" y="350" style="font-weight:normal;font-size:279px;font-family:\'Nunito\';text-anchor:middle;fill:#fff">A</text>
+			<text x="50%" y="350" style="font-weight:normal;font-size:280px;font-family:\'Noto Sans\';text-anchor:middle;fill:#fff">A</text>
 		</svg>';
 		$this->assertEquals($avatar, $svg);
 	}
diff --git a/lib/private/Avatar/Avatar.php b/lib/private/Avatar/Avatar.php
index 4468af8205335a8a2ef00787c6b6b1da1ba5a3eb..172f47d12a80b7eaf463d1663861dbf7c89616e3 100644
--- a/lib/private/Avatar/Avatar.php
+++ b/lib/private/Avatar/Avatar.php
@@ -50,8 +50,8 @@ abstract class Avatar implements IAvatar {
 	/**
 	 * https://github.com/sebdesign/cap-height -- for 500px height
 	 * Automated check: https://codepen.io/skjnldsv/pen/PydLBK/
 	 * Nunito cap-height is 0.716 and we want a 200px caps height size
 	 * (0.4 letter-to-total-height ratio, 500*0.4=200), so: 200/0.716 = 279px.
 	 * Since we start from the baseline (text-anchor) we need to
 	 * shift the y axis by 100px (half the caps height): 500/2+100=350
 	 *
@@ -60,7 +60,7 @@ abstract class Avatar implements IAvatar {
 	private $svgTemplate = '<?xml version="1.0" encoding="UTF-8" standalone="no"?>
 		<svg width="{size}" height="{size}" version="1.1" viewBox="0 0 500 500" xmlns="http://www.w3.org/2000/svg">
 			<rect width="100%" height="100%" fill="#{fill}"></rect>
-			<text x="50%" y="350" style="font-weight:normal;font-size:279px;font-family:\'Nunito\';text-anchor:middle;fill:#fff">{letter}</text>
+			<text x="50%" y="350" style="font-weight:normal;font-size:280px;font-family:\'Noto Sans\';text-anchor:middle;fill:#fff">{letter}</text>
 		</svg>';
 
 	/**
@@ -141,7 +141,7 @@ abstract class Avatar implements IAvatar {
 			return false;
 		}
 		try {
-			$font = __DIR__ . '/../../core/fonts/Nunito-Regular.ttf';
+			$font = __DIR__ . '/../../core/fonts/NotoSans-Regular.ttf';
 			$svg = $this->getAvatarVector($size);
 			$avatar = new Imagick();
 			$avatar->setFont($font);
@@ -176,7 +176,7 @@ abstract class Avatar implements IAvatar {
 		$white = imagecolorallocate($im, 255, 255, 255);
 		imagefilledrectangle($im, 0, 0, $size, $size, $background);
 
-		$font = __DIR__ . '/../../../core/fonts/Nunito-Regular.ttf';
+		$font = __DIR__ . '/../../../core/fonts/NotoSans-Regular.ttf';
 
 		$fontSize = $size * 0.4;
 		list($x, $y) = $this->imageTTFCenter(
@@ -50,8 +50,8 @@ abstract class Avatar implements IAvatar {
 	 * https://github.com/sebdesign/cap-height -- for 500px height
 	 * Automated check: https://codepen.io/skjnldsv/pen/PydLBK/
-	 * Nunito cap-height is 0.716 and we want a 200px caps height size
-	 * (0.4 letter-to-total-height ratio, 500*0.4=200), so: 200/0.716 = 279px.
+	 * Noto Sans cap-height is 0.715 and we want a 200px caps height size
+	 * (0.4 letter-to-total-height ratio, 500*0.4=200), so: 200/0.715 = 280px.
 	 * Since we start from the baseline (text-anchor) we need to
 	 * shift the y axis by 100px (half the caps height): 500/2+100=350